import React, { useEffect } from 'react';
import L from 'leaflet';
import 'leaflet/dist/leaflet.css';
import '../index.css';

import configDefult from '../Default/configs';

import { MarkerOptionsDefault } from '../Default/MarkerOptions';
const { Icon, Marker, Popup } = MarkerOptionsDefault;

// themes => dark_all, spotify_dark

export default function Map({ options, children }){
  let map;
  let id;
  // const [ id, setId ] = useState([]);

  useEffect(() => {
    function init() {
      if(!options) options = configDefult;
      const { params = configDefult.params, theme = 'dark_all' } = options;
      // console.log(options)
      let tileLayer = configDefult.tileLayer;
      tileLayer.uri = `http://{s}.basemaps.cartocdn.com/${theme}/{z}/{x}/{y}.png`;
      let config = {
        params,
        tileLayer
      }
      // essa função cria o objeto de mapa do Leaflet e é chamada após a montagem do componente Map
      map = L.map(id, config.params);
      if (config.params.controls){
        L.control.zoom({ position: "bottomleft"}).addTo(map);
        L.control.scale({ position: "bottomleft"}).addTo(map);
      }
      // um TileLayer é usado como o "mapa base"
      // const TileLayer = L.tileLayer(config.tileLayer.uri, config.tileLayer.params).addTo(map);
      L.tileLayer(config.tileLayer.uri, config.tileLayer.params).addTo(map);
    }

    init();
  }, []);

  useEffect(() => {
    function createMarker({ props }){
      const { markerOptions = MarkerOptionsDefault } = props;
      if(!markerOptions.icon) markerOptions.Icon = Icon;
      if(!markerOptions.marker) markerOptions.marker = Marker;
      if(!markerOptions.popup) markerOptions.popup = Popup;

      const { icon = Icon, marker = Marker, popup = Popup } = markerOptions;
      const { content, options } = popup;
      // console.log(content)

      let customIcon = L.icon(icon);
      marker.icon = customIcon;

      const newMarker = new L.Marker(props.coordinates, marker);

      newMarker.bindPopup(content, options).openPopup();
      newMarker.addTo(map);
      console.log(map)
    }
    children.map(child => {
      if(child.type instanceof Function){
        // console.log(child.type)
        createMarker(child)
      }
    })
  }, [map]);

  return (
    <div id="mapUI">
      <div ref={(node) => {
        id = node
      }} id="map" />
    </div>
  );
}
